@@ -18,10 +18,13 @@ from mindbridgeapi.generated_pydantic_model.model import ApiLibraryRead
 
 
 def _empty_analysis_types() -> Generator[AnalysisTypeItem, None, None]:
-    """Empty generator function
+    """Empty generator function.
 
     This returns an empty generator function, it's use is to ensure analysis_types is
     not None for the LibraryItem class
+
+    Yields:
+        AnalysisTypeItem: Will never yield anything
     """
     yield from ()
 
